@@ -198,11 +198,15 @@
 					(TweakRelativeOffset sa-tag offsetx offsety)))
 		;;; not a standalone directive				
 		(begin
+      ;;(if (equal? grob "BassFigure")
+        ;;(d-AdjustBassFigureHeight offsety))
+        
 			(if tag
 				(eval-string (string-append "(d-" tag "  (list (cons 'offsetx \"" offsetx "\")  (cons 'offsety \"" offsety "\")))")))
 			(if (Rest?)
 				(ExtraOffset "RestOffset" "Rest" "chord" "Voice." (cons offsetx offsety) DENEMO_OVERRIDE_AFFIX)
-				(disp "Doing Nothing"))))
+				(if (equal? grob "BassFigure")
+          (d-AdjustBassFigureHeight offsety)))))
 	(d-SetSaved #f))
 ;;;;;;;;;;;
 (define (SetSlur control-points)
@@ -334,6 +338,9 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
 						  (if choice
 								(eval-string (string-append "(d-" tag " (list (cons 'direction \"" choice "\")))")))))
 	
+  (define (do-padding)
+		(let ((padding (d-GetUserInput (_ "Padding") (_ "Give amount of padding required around this item (in staff spaces)") "2")))
+								(eval-string (string-append "(d-" tag " (list (cons 'padding \"" padding "\")))"))))
 							
 							
 	(define (alter-text)
@@ -376,7 +383,7 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
 								
 					((equal? target-type "Chord")
 							(let ((menu ""))
-								(set! menu (list  (cons (_ "Up/Down") do-direction) (cons (_ "Offset Position") do-center-relative-offset)))   
+								(set! menu (list  (cons (_ "Up/Down") do-direction) (cons (_ "Padding") do-padding) (cons (_ "Offset Position") do-center-relative-offset)))   
 								;;; FIXME the value is relative to the centre line of the staff, this gets relative to the tr sign.
 								;;;need to use d-GetNewTarget to find the notehead position, then use its mid_c_offset to get the centre line value
 								;;; beaming does this
@@ -391,14 +398,23 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
 								
 				((equal? target-type "Note")
 					(if grob   ;;; is grob defined for Fingering, or should this be tag? FIXME
-						(cond ((equal? grob "Fingering")
-							(set! choice (d-PopupMenu (list (cons (cons "Control Fingerings Positions" 
+						(cond
+              ((equal? grob "Fingering")
+                (set! choice (d-PopupMenu (list (cons (cons "Control Fingerings Positions" 
 									"Creates a directive before this chord which can be edited to position the finger indications for each note in the chord") 
 										d-FingeringPosition))))
-							(if choice
-								(choice)
-								(disp "cancelled"))))
-							(let ((menu '()) (base-duration (d-GetNoteBaseDuration)))
+                (if choice
+                  (choice)
+                  (disp "cancelled")))
+              ((equal? grob "BassFigure")
+                  (set! choice (d-PopupMenu (list (cons (cons "Offset Figure" 
+									"Choose position for this bass figure") 
+										do-center-relative-offset))))
+                  (if choice
+                    (choice)
+                    (disp "cancelled")))
+                  )
+            (let ((menu '()) (base-duration (d-GetNoteBaseDuration)))
 									(set! menu (cons (cons (cons (_ "Line Break") (_ "Start a new line here"))	d-LineBreak) menu))
 									(set! menu (cons (cons (cons (_"Page Break") (_"Start a new page here"))	d-PageBreak) menu))
 									(if (> base-duration 5)
@@ -438,11 +454,15 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
 											
 ;;;; Toggles a postfix annotation on a chord, with editing for direction or offset
 (define* (ChordAnnotation tag lilypond params graphic #:optional display)
+  (define current-direction "^")
 	(define (set-option option)
+          (if (not (or (equal? current-direction "^") (equal? current-direction "-") (equal? current-direction "_")))
+            (set! current-direction "-"))
 					(case (car option)
+              ((padding) (string-append " " current-direction "\\tweak #'padding #" (cdr option)))
 							((direction) (cdr option))
-							((offsetx) (string-append " ^\\tweak #'X-offset #'" (cdr option)))
-							((offsety)  (string-append " ^\\tweak #'Y-offset #'" (cdr option)))))
+							((offsetx) (string-append " " current-direction "\\tweak #'X-offset #'" (cdr option)))
+							((offsety)  (string-append " " current-direction "\\tweak #'Y-offset #'" (cdr option)))))
 	(define (direction-edit)
 		(let ((choice #f))
 		(set! choice (d-GetOption  (string-append (_ "Up") stop (_ "Down") stop (_ "Auto") stop)))
@@ -453,7 +473,7 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
 															((equal? choice (_ "Auto")) "-")))
 					(d-DirectivePut-chord-postfix tag (string-append  (string-append choice " " lilypond " ")))
 					(d-SetSaved #f)))))
-					
+  
 	(if (and (d-Directive-chord? tag) (equal? params "edit"))
 						(case (GetEditOption)
 								((edit) (direction-edit))
@@ -466,6 +486,7 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
 								(if (and (d-Directive-chord? tag) (list? params))
 									(begin
 										(d-SetSaved #f)
+                    (set! current-direction (substring (string-trim (d-DirectiveGet-chord-postfix tag)) 0 1))
 										(d-DirectivePut-chord-postfix tag (string-append  (string-join (map set-option params)) " " lilypond " ")))
 									(d-WarningDialog "Cannot complete operation - cursor moved or bad parameter list")))
 							(begin  ;;;no parameters, toggle annotation off/on
