@@ -306,9 +306,7 @@ open_for_real (gchar * filename, DenemoGUI * gui, DenemoSaveType template, Impor
 #define EXISTS(extension) (strcmp (filename + strlen (filename) - strlen(extension), extension) == 0)
   if (g_file_test (filename, G_FILE_TEST_EXISTS))
     {
-      if (EXISTS (".denemo"))
-        xml = TRUE, result = importXML (filename, gui, type);
-      else if (EXISTS (".dnm"))
+      if (EXISTS (".denemo") || EXISTS (".dnm"))
         xml = TRUE, result = importXML (filename, gui, type);
       else if (EXISTS (".ly"))
         result = lyinput (filename);
@@ -446,7 +444,7 @@ save_in_format (gint format_id, DenemoGUI * gui, gchar * filename)
          */
 
         if ((!gui->has_script) && getNumCharsSchemeText ())
-          if (!confirm ("You have a Script defined", "Use this script every time this file is opened?"))
+          if (!confirm (_("You have a Script defined"), _("Use this script every time this file is opened?")))
             {
               deleteSchemeText ();
             }
@@ -535,7 +533,7 @@ init_local_path (void)
   gboolean err = g_mkdir_with_parents (local_template_path, 0770);
   if (err)
     {
-      warningdialog ("Could not create .denemo/templates for you personal templates");
+      warningdialog (_("Could not create .denemo/templates for you personal templates"));
       g_free (local_template_path);
       local_template_path = NULL;
     }
@@ -575,7 +573,7 @@ template_open (DenemoGUI * gui, TemplateType local, gchar * filename)
           GDir *denemo_path = g_dir_open (system_example_path, 0, NULL);
           if (denemo_path == NULL)
             {
-              warningdialog ("No examples directory in installation");
+              warningdialog (_("No examples directory in installation"));
               system_example_path = NULL;
             }
         }
@@ -589,7 +587,7 @@ template_open (DenemoGUI * gui, TemplateType local, gchar * filename)
           GDir *denemo_path = g_dir_open (system_template_path, 0, NULL);
           if (denemo_path == NULL)
             {
-              warningdialog ("No templates directory in installation");
+              warningdialog (_("No templates directory in installation"));
               system_template_path = NULL;
             }
         }
@@ -784,9 +782,7 @@ update_preview_cb (GtkFileChooser * file_chooser, gpointer data)
   thumb_filename = large_thumbnail_name (selection_filename);
   pixbuf = gdk_pixbuf_new_from_file_at_size (thumb_filename, 512, 512, NULL);
   have_preview = (pixbuf != NULL);
-#ifdef DEBUG
-  printf ("\n# %s for %s thumbnail = %s\n", have_preview ? "We have a thumbnail generated" : "We have not yet generated a thumbnail", selection_filename, thumb_filename);
-#endif
+  g_debug ("\n# %s for %s thumbnail = %s\n", have_preview ? "We have a thumbnail generated" : "We have not yet generated a thumbnail", selection_filename, thumb_filename);
   g_free (selection_filename);
   g_free (thumb_filename);
 
@@ -838,7 +834,7 @@ update_preview_cb (GtkFileChooser * file_chooser, gpointer data)
       gchar *name =\
 	gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_selection));\
       if((ret=open_for_real (name, gui, template, type))) {\
-	gchar *warning = g_strdup_printf("Load of file %s failed", name);\
+	gchar *warning = g_strdup_printf(_("Load of file %s failed"), name);\
 	warningdialog(warning);\
 	g_free(warning);\
       }\
@@ -954,7 +950,7 @@ file_savewrapper (GtkAction * action, DenemoScriptParam * param)
     {
       if (action && Denemo.gui->filename && Denemo.gui->filename->len)
         {
-          warningdialog ("File Save **FAILED**");
+          warningdialog (_("File save failed"));
           score_status (gui, TRUE);
         }
       else
@@ -1172,7 +1168,7 @@ selection_received (G_GNUC_UNUSED GtkClipboard * clipboard, const gchar * text,
 {
   if (!text)
     {
-      warningdialog ("No selection text available");
+      warningdialog (_("No selection text available"));
       return;
     }
   gchar *filename = g_build_filename (locatedotdenemo (), "denemopaste.ly", NULL);
@@ -1193,12 +1189,12 @@ selection_received (G_GNUC_UNUSED GtkClipboard * clipboard, const gchar * text,
           gtk_widget_destroy (Denemo.page);
           Denemo.guis = g_list_remove (Denemo.guis, gui);
           g_free (gui);
-          warningdialog ("Could not interpret selection as LilyPond notes");
+          warningdialog (_("Could not interpret selection as LilyPond notes"));
           return;
         }
       dnm_setinitialclef (Denemo.gui->si, (DenemoStaff *) Denemo.gui->si->currentstaff->data, theclef);
       call_out_to_guile ("(while (and (None?) (d-MoveToStaffDown)) (begin (d-MoveToStaffUp)(d-DeleteStaff)))");
-      if (confirm ("Paste from Selection", "Paste this music into your score?"))
+      if (confirm (_("Paste from Selection"), _("Paste this music into your score?")))
         {
           DenemoGUI *gui = Denemo.gui;
           tohome (NULL, NULL);
@@ -1219,7 +1215,7 @@ paste_clipboard (GtkAction * action, DenemoScriptParam * param)
 {
   if (Denemo.gui != g_list_last (Denemo.guis)->data)
     {
-      warningdialog ("Can only paste LilyPond text into the last tab, sorry");
+      warningdialog (_("Can only paste LilyPond text into the last tab, sorry"));
       return;
     }
   GtkClipboard *clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
