@@ -67,7 +67,7 @@ fluidsynth_init (DenemoPrefs * config, unsigned int samplerate)
     }
   else
     {
-      g_warning ("\nThe default soundfont has been loaded\n");
+      g_warning ("The default fluidsynth soundfont has been loaded");
     }
 
   // select bank 0 and preset 0 in the soundfont we just loaded on channel 0
