@@ -49,6 +49,29 @@
 
 static void load_keymap_files (gchar * keymapfile, gchar * fallback);
 
+gboolean
+is_action_id_builtin(gint id)
+{
+  command_row command;
+  keymap_get_command_row(Denemo.map, &command, id);
+  return command.script_type == COMMAND_BUILTIN;
+}
+
+gboolean
+is_action_name_builtin(gchar* command_name)
+{
+  gint* id = NULL;
+
+  id = g_hash_table_lookup (Denemo.map->idx_from_name, command_name);
+  if(!id)
+  {
+    g_debug("Requesting a invalid action name");
+    return TRUE;
+  }
+  
+  return is_action_id_builtin(*id);
+}
+
 void
 command_row_init(command_row *command)
 {
@@ -61,6 +84,8 @@ command_row_init(command_row *command)
   command->callback = NULL;
   command->action = NULL;
   command->type = KeymapEntry;
+  command->script_type = COMMAND_BUILTIN;
+  command->locations = NULL;
 }
 
 void
@@ -370,8 +395,10 @@ dnm_accelerator_name (guint accelerator_key, GdkModifierType accelerator_mods)
 
       name = g_string_new (gdk_keyval_name (accelerator_key));
       if (name->len > 3 && (*name->str == 'K') && (*(name->str + 1) == 'P') && (*(name->str + 2) == '_'))
-        g_string_erase (name, 0, 3);    //force numeric keypad KP_ names to normal
-
+        {
+          if((*(name->str + 3) !='7') && (*(name->str + 3) !='8') && (*(name->str + 3) !='9'))
+            g_string_erase (name, 0, 3);    //force numeric keypad KP_ names to normal except for 7 8 9 which are not needed for duration entry
+        }
       //g_print("label %s\nname %s\n", gtk_accelerator_get_label(accelerator_key, 0), gdk_keyval_name(accelerator_key));
       // g_print("mods were %x\n", accelerator_mods);
 #if 0
@@ -564,7 +591,9 @@ allocate_keymap (void)
                                              G_TYPE_POINTER,            //callback
                                              GTK_TYPE_LIST_STORE,       //bindings
                                              G_TYPE_BOOLEAN,            //hidden
-                                             G_TYPE_BOOLEAN             //deleted
+                                             G_TYPE_BOOLEAN,            //deleted
+                                             G_TYPE_INT,                //type
+                                             G_TYPE_POINTER
     );
 
   //empty index reference
@@ -619,6 +648,8 @@ void register_command_row(keymap* the_keymap, command_row* command){
                       COL_TOOLTIP, command->tooltip,
                       COL_CALLBACK, command->callback,
                       COL_BINDINGS, command->bindings,
+                      COL_SCRIPTTYPE, command->script_type,
+                      COL_LOCATIONS, command->locations,
                       -1);
   //insert the command name in the index reference
   g_hash_table_insert (the_keymap->idx_from_name, g_strdup (command->name), value);
@@ -694,12 +725,12 @@ alphabeticalize_commands (keymap * the_keymap)
 
 //False if command_idx is an invalid index or keymap is null, true otherwise
 //TODO keymap should not be NULL
-static gboolean
+gboolean
 keymap_get_command_row (keymap * the_keymap, command_row * row, guint command_idx)
 {
   if (!the_keymap)
     {
-      warningdialog ("This should not happen...");
+      warningdialog (_("This should not happen..."));
       return FALSE;
     }
   GtkTreeModel *model = GTK_TREE_MODEL (the_keymap->commands);
@@ -716,6 +747,8 @@ keymap_get_command_row (keymap * the_keymap, command_row * row, guint command_id
                       COL_BINDINGS, &row->bindings,
                       COL_HIDDEN, &row->hidden,
                       COL_DELETED, &row->deleted,
+                      COL_SCRIPTTYPE, &row->script_type,
+                      COL_LOCATIONS, &row->locations,
                       -1);
   return TRUE;
 }
@@ -1449,7 +1482,6 @@ execute_callback_from_idx (keymap * the_keymap, guint command_idx)
 gboolean
 execute_callback_from_name (const gchar * command_name)
 {
-  gboolean res = TRUE;
   gchar *text = NULL;
   GtkAction *action = action_of_name (the_keymap, (gchar *) command_name);
   text = (gchar *) g_object_get_data (G_OBJECT (action), "scheme");
@@ -1457,7 +1489,7 @@ execute_callback_from_name (const gchar * command_name)
     call_out_to_guile (text);
   else
     gtk_action_activate (action);
-  return res;
+  return TRUE;
 }
 
 //prints info on the data of the keymap relative to a command
@@ -1516,7 +1548,7 @@ locatekeymapdir ()
   err = g_mkdir_with_parents (keymapdir, 0770);
   if (err)
     {
-      warningdialog ("Could not create .denemo/actions for your customized commands");
+      warningdialog (_("Could not create .denemo/actions for your customized commands"));
       g_free (keymapdir);
       keymapdir = NULL;
     }
@@ -1572,7 +1604,7 @@ load_keymap_dialog (GtkWidget * widget)
   if (keymapdir)
     load_keymap_dialog_location (widget, keymapdir);
   else
-    warningdialog ("Cannot access your local .denemo");
+    warningdialog (_("Cannot access your local .denemo"));
   g_free (keymapdir);
 }
 
@@ -1584,7 +1616,7 @@ load_system_keymap_dialog (GtkWidget * widget)
   if (systemwide)
     load_keymap_dialog_location (widget, systemwide);
   else
-    warningdialog ("Installation error");
+    warningdialog (_("Installation error"));
   g_free (systemwide);
 }
 
@@ -1599,11 +1631,9 @@ static void
 load_keymap_files (gchar * localrc, gchar * systemwide)
 {
 
-  if (localrc && (0 == load_xml_keymap (localrc, TRUE)))
+  if (localrc && (0 == load_xml_keymap (localrc)))
     return;
-  load_xml_keymap (systemwide, TRUE);
-  return;
-
+  load_xml_keymap (systemwide);
 }
 
 /**
