@@ -7,12 +7,9 @@
 #ifndef KBDINTERFACE_H
 #define KBDINTERFACE_H
 
-void
-configure_keyboard_dialog (GtkAction *action, gpointer param);
+void configure_keyboard_dialog (GtkAction * action, gpointer param);
 
-void
-configure_keyboard_dialog_init_idx (GtkAction * action, DenemoGUI * gui,
-				    gint command_idx);
+void configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx);
 
 
 #endif
