@@ -3,17 +3,38 @@
 #include "view.h"
 #include "mousing.h"
 
+static gchar*
+find_command_dir(GtkAction* action, gchar* filename)
+{
+  gchar *menupath = (gchar *) g_object_get_data (G_OBJECT (action), "menupath");
+  gchar* dirs[] = {
+      g_build_filename (locatedotdenemo (), "actions", "menus", menupath, NULL),
+      g_build_filename (locatedotdenemo (), "download", "actions", "menus", menupath, NULL),
+      g_build_filename (get_data_dir (), "actions", "menus", menupath, NULL),
+      NULL
+  };
+  return find_dir_for_file (filename, dirs);
+}
+
+static int
+get_command_type(xmlChar* type)
+{
+  return 0 == xmlStrcmp (type, COMMAND_TYPE_SCHEME) ? COMMAND_SCHEME : COMMAND_BUILTIN;
+}
+
 static void
-parseScripts (xmlDocPtr doc, xmlNodePtr cur, gchar * fallback, gint merge)
+parseScripts (xmlDocPtr doc, xmlNodePtr cur, gchar * fallback)
 {
   command_row command;
   command_row_init(&command);
-  xmlChar *menupath = NULL, *scheme = NULL, *after = NULL;
-  GList *menupaths = NULL;
-  cur = cur->xmlChildrenNode;
-  gboolean is_script = FALSE;
+  xmlChar *after = NULL, *type = NULL;
 
-  for (; cur; cur = cur->next)
+  type = xmlGetProp(cur, COMMANDXML_TAG_TYPE);
+  if(type && 0 == xmlStrcmp (type, COMMAND_TYPE_SCHEME))
+    command.script_type = get_command_type(type);
+  xmlFree(type);
+
+  for (cur = cur->xmlChildrenNode; cur; cur = cur->next)
     {
       if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_ACTION))
         {
@@ -24,23 +45,18 @@ parseScripts (xmlDocPtr doc, xmlNodePtr cur, gchar * fallback, gint merge)
           else
             {
               command.name = (gchar*) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
-              //We allow multiple menupaths for a given action, all are added to the gtk_ui when this command is processed after the tooltip node. This is very bad xml, as the action should have all the others as children, and not depend on the order.FIXME
-              menupaths = NULL;
+              // We allow multiple locations for a given action, all are added to the gtk_ui when this command is processed after the tooltip node. 
+              // This is very bad xml, as the action should have all the others as children, and not depend on the order.FIXME
+              command.locations = NULL;
             }
         }
-      else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_SCHEME))
-        {
-          scheme = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
-          is_script = TRUE;
-        }
       else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_HIDDEN))
         {
           command.hidden = TRUE;
         }
       else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_MENUPATH))
         {
-          menupath = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
-          menupaths = g_list_append (menupaths, menupath);
+          command.locations = g_list_append (command.locations, xmlNodeListGetString (doc, cur->xmlChildrenNode, 1));
         }
       else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_LABEL))
         {
@@ -55,10 +71,9 @@ parseScripts (xmlDocPtr doc, xmlNodePtr cur, gchar * fallback, gint merge)
           command.tooltip = _((gchar*) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1));
         }
     }
-  create_command(is_script, (gchar*) scheme, (gchar*) after, (gchar*) menupath, fallback, menupaths, merge, &command);
+  create_command((gchar*) after, fallback, &command);
 }
 
-
 static void
 parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
 {
@@ -80,9 +95,7 @@ parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
             {
               name = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
               show_action_of_name ((gchar*) name);
-#ifdef DEBUG
-              g_print ("Action %s\n", (gchar *) name);
-#endif         /*DEBUG*/
+              g_debug ("Action %s\n", (gchar *) name);
             }
         }
       else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_HIDDEN))
@@ -112,9 +125,7 @@ parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
                       keyval = 0;
                       if (Denemo.prefs.strictshortcuts)
                         dnm_accelerator_parse (gtk_binding, &keyval, &state);
-#ifdef DEBUG
-                      g_print ("binding %s, keyval %d, state %d, Command Number %d\n", gtk_binding, keyval, state, command_number);
-#endif
+                      g_debug ("binding %s, keyval %d, state %d, Command Number %d\n", gtk_binding, keyval, state, command_number);
                       {
                         gchar *comma;
                         comma = strtok (gtk_binding, ",");
@@ -142,7 +153,6 @@ parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
                 }
             }
         }
-
     }
 }
 
@@ -178,7 +188,6 @@ parseCursorBinding (xmlDocPtr doc, xmlNodePtr cur)
     }
 }
 
-
 static void
 parseCursors (xmlDocPtr doc, xmlNodePtr cur)
 {
@@ -191,10 +200,8 @@ parseCursors (xmlDocPtr doc, xmlNodePtr cur)
     }
 }
 
-
-
 static void
-parseCommands (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar * menupath, gint merge)
+parseCommands (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar * menupath)
 {
   xmlNodePtr ncur;
 
@@ -204,7 +211,7 @@ parseCommands (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar * menup
     {
       if ((0 == xmlStrcmp (ncur->name, COMMANDXML_TAG_ROW)))
         {
-          parseScripts (doc, ncur, menupath, merge);
+          parseScripts (doc, ncur, menupath);
         }
     }
 
@@ -224,18 +231,17 @@ parseCommands (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar * menup
 }
 
 static void
-parseKeymap (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar * menupath, gint merge)
+parseKeymap (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar * menupath)
 {
   for (cur = cur->xmlChildrenNode; cur != NULL; cur = cur->next)
     {
       if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_MAP))
         {
-          parseCommands (doc, cur, the_keymap, menupath, merge);
+          parseCommands (doc, cur, the_keymap, menupath);
         }
     }
 }
 
-
 /* 
  * load a command from filename. 
  * if not scripted and merging with other commands, tell the user where the new command is. 
@@ -247,17 +253,16 @@ parseKeymap (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar * menupat
  * negative on failure
  */
 gint
-load_xml_keymap (gchar * filename, gboolean interactive)
+load_xml_keymap (gchar * filename)
 {
   gint ret = -1;
   xmlDocPtr doc;
-  //xmlNsPtr ns;
   xmlNodePtr rootElem;
   if (filename == NULL)
     return ret;
   if (g_file_test (filename, G_FILE_TEST_IS_DIR))
     {
-      warningdialog ("There is no support for loading whole folders of commands yet, sorry");
+      warningdialog (_("There is no support for loading whole folders of commands yet, sorry"));
       return ret;
     }
   if (!g_file_test (filename, G_FILE_TEST_EXISTS))
@@ -289,12 +294,8 @@ load_xml_keymap (gchar * filename, gboolean interactive)
 
   while (rootElem != NULL)
     {
-#ifdef DEBUG
-      g_print ("RootElem %s\n", rootElem->name);
-#endif
-
-
-      parseKeymap (doc, rootElem, Denemo.map, menupath, interactive);
+      g_debug ("RootElem %s\n", rootElem->name);
+      parseKeymap (doc, rootElem, Denemo.map, menupath);
 
       if (Denemo.last_merged_command)
         g_free (Denemo.last_merged_command);
@@ -310,7 +311,8 @@ load_xml_keymap (gchar * filename, gboolean interactive)
 
   xmlFreeDoc (doc);
 
-  {                             //if this is a new-style .commands file, we need to load the keybindings separately
+  {
+    //if this is a new-style .commands file, we need to load the keybindings separately
     gchar *name = g_strdup (filename);
     gchar *ext = remove_extension (name);
     if (ext && !strcmp (ext, "commands"))
@@ -382,14 +384,11 @@ load_xml_keybindings (gchar * filename)
   return ret;
 }
 
-
 static void
 write_xml_keybinding_info (gchar * kb_name, xmlNodePtr node)
 {
   gchar *dnm_binding = translate_binding_gtk_to_dnm (kb_name);
-#ifdef DEBUG
-  g_print ("binding is : (dnm) %s, (gtk) %s \n", dnm_binding, kb_name);
-#endif
+  g_debug ("binding is : (dnm) %s, (gtk) %s \n", dnm_binding, kb_name);
   if (!(Denemo.prefs.return_key_is_special && !strcmp (dnm_binding, N_("Return"))))
     xmlNewTextChild (node, NULL, (xmlChar *) "bind", (xmlChar *) dnm_binding);
   g_free (dnm_binding);
@@ -418,13 +417,14 @@ save_xml_keymap (gchar * filename)      //_!!! create a DEV version here, saving
   keymap *the_keymap = Denemo.map;
   gint i, ret = -1;
   xmlDocPtr doc;
-  //xmlNsPtr ns;
   xmlNodePtr parent, child;
+  gchar* cfilename = NULL;
+  const gchar *basename = NULL;
+  gchar* dir = NULL;
 
   doc = xmlNewDoc ((xmlChar *) "1.0");
   doc->xmlRootNode = parent = xmlNewDocNode (doc, NULL, COMMANDXML_TAG_ROOT, NULL);
 
-
   child = xmlNewChild (parent, NULL, COMMANDXML_TAG_MERGE, NULL);
 
   xmlNewTextChild (child, NULL, COMMANDXML_TAG_TITLE, (xmlChar *) "A Denemo Command Set");
@@ -439,31 +439,48 @@ save_xml_keymap (gchar * filename)      //_!!! create a DEV version here, saving
 
   for (i = 0; i < keymap_size (the_keymap); i++)
     {
-
-
       gpointer action = (gpointer) lookup_action_from_idx (the_keymap, i);
-      gchar *scheme = action ? g_object_get_data (action, "scheme") : NULL;
       gchar *after = action ? g_object_get_data (action, "after") : NULL;
       gboolean deleted = (gboolean) (action ? GPOINTER_TO_INT (g_object_get_data (action, "deleted")) : 0);
-      //  if(deleted && scheme)
-      //        continue;
+      gchar *name = (gchar *) lookup_name_from_idx (the_keymap, i);
+
+      basename = gtk_action_get_name (action);
+
+      if(!is_action_name_builtin(name))
+      {
+        // Check if the command metada file exists
+        cfilename = g_strconcat (basename, XML_EXT, NULL);
+        dir = find_command_dir(action, cfilename);
+        g_free(cfilename);
+        if(!dir)
+        {
+          g_warning("Unable to find metadata file for script %s", name);
+          continue;
+        }
+
+        // Check if the command data file exists
+        cfilename = g_strconcat (basename, SCM_EXT, NULL);
+        dir = find_command_dir(action, cfilename);
+        g_free(cfilename);
+        if(!dir)
+        {
+          g_warning("Unable to find data file for script %s", name);
+          continue;
+        }
+      }
 
       child = xmlNewChild (parent, NULL, COMMANDXML_TAG_ROW, NULL);
 
-
-      gchar *name = (gchar *) lookup_name_from_idx (the_keymap, i);
-#ifdef DEBUG
-      g_print ("%s \n", name);
-#endif
       xmlNewTextChild (child, NULL, COMMANDXML_TAG_ACTION, (xmlChar *) name);
       if (after)
         xmlNewTextChild (child, NULL, COMMANDXML_TAG_AFTER, (xmlChar *) after);
       if (deleted)              //store as hidden in commands file
         xmlNewTextChild (child, NULL, COMMANDXML_TAG_HIDDEN, (xmlChar *) "true");
 
-      if (scheme)
-        xmlNewTextChild (child, NULL, COMMANDXML_TAG_SCHEME,
-                         /* (xmlChar *) scheme */ (xmlChar *) "");
+      if(!is_action_name_builtin(name))
+          xmlNewProp(child, COMMANDXML_TAG_TYPE, COMMAND_TYPE_SCHEME);
+      else
+          xmlNewProp(child, COMMANDXML_TAG_TYPE, COMMAND_TYPE_BUILTIN);
 
       gchar *menupath = action ? g_object_get_data (action, "menupath") : NULL;
       if (menupath)
@@ -483,7 +500,7 @@ save_xml_keymap (gchar * filename)      //_!!! create a DEV version here, saving
 
     }
 
-  xmlSaveFormatFileEnc (filename, doc, "UTF-8", 1);
+  xmlSaveFormatFileEnc (filename, doc, XML_ENCODING, 1);
 
   xmlFreeDoc (doc);
   return ret;
@@ -515,19 +532,16 @@ save_xml_keybindings (gchar * filename)
   for (i = 0; i < keymap_size (the_keymap); i++)
     {
       gpointer action = (gpointer) lookup_action_from_idx (the_keymap, i);
-      gchar *scheme = action ? g_object_get_data (action, "scheme") : NULL;
       gboolean deleted = (gboolean) (action ? GPOINTER_TO_INT (g_object_get_data (action, "deleted")) : 0);
       gboolean hidden = (gboolean) (action ? GPOINTER_TO_INT (g_object_get_data (action, "hidden")) : 0);
-      if (deleted && scheme)
+      if (deleted && !is_action_id_builtin(i))
         continue;
       if (hidden || command_has_binding (i))
         {
           child = xmlNewChild (parent, NULL, COMMANDXML_TAG_ROW, NULL);
 
           gchar *name = (gchar *) lookup_name_from_idx (the_keymap, i);
-#ifdef DEBUG
-          g_print ("%s %s binding(s) \n", name, command_has_binding (i) ? "has" : "does not have");
-#endif
+          g_debug ("%s %s binding(s) \n", name, command_has_binding (i) ? "has" : "does not have");
           xmlNewTextChild (child, NULL, COMMANDXML_TAG_ACTION, (xmlChar *) name);
           if (hidden)
             xmlNewTextChild (child, NULL, COMMANDXML_TAG_HIDDEN, (xmlChar *) "true");
@@ -536,7 +550,7 @@ save_xml_keybindings (gchar * filename)
         }
     }
 
-  xmlSaveFormatFileEnc (filename, doc, "UTF-8", 1);
+  xmlSaveFormatFileEnc (filename, doc, XML_ENCODING, 1);
 
   xmlFreeDoc (doc);
   return ret;
@@ -628,7 +642,6 @@ parse_paths (gchar * filename, DenemoGUI * gui)
 {
   gint ret = -1;
   xmlDocPtr doc;
-  //xmlNsPtr ns;
   xmlNodePtr rootElem;
   if (filename == NULL)
     return ret;
@@ -647,27 +660,24 @@ parse_paths (gchar * filename, DenemoGUI * gui)
       xmlFreeDoc (doc);
       return ret;
     }
-  //g_print ("RootElem %s\n", rootElem->name);
+
   if (xmlStrcmp (rootElem->name, (const xmlChar *) "ui"))
     {
       g_warning ("Document has wrong type\n");
       xmlFreeDoc (doc);
       return ret;
     }
-  gchar *path = "";
-  parseMenu (rootElem, path, gui);
+
+  parseMenu (rootElem, "", gui);
   ret = 0;
   xmlFreeDoc (doc);
   return ret;
 }
 
-
-
 gint
-save_script_as_xml (gchar * filename, gchar * myname, gchar * myscheme, gchar * mylabel, gchar * mytooltip, gchar * after)
+save_command_metadata (gchar * filename, gchar * myname, gchar * mylabel, gchar * mytooltip, gchar * after)
 {
   xmlDocPtr doc;
-  //xmlNsPtr ns;
   xmlNodePtr parent, child;
 
   doc = xmlNewDoc ((xmlChar *) "1.0");
@@ -680,19 +690,72 @@ save_script_as_xml (gchar * filename, gchar * myname, gchar * myscheme, gchar *
   parent = xmlNewChild (child, NULL, COMMANDXML_TAG_MAP, NULL);
 
   child = xmlNewChild (parent, NULL, COMMANDXML_TAG_ROW, NULL);
+  xmlNewProp(child, COMMANDXML_TAG_TYPE, COMMAND_TYPE_SCHEME);
+
   if (after)
     xmlNewTextChild (child, NULL, COMMANDXML_TAG_AFTER, (xmlChar *) after);
 
   xmlNewTextChild (child, NULL, COMMANDXML_TAG_ACTION, (xmlChar *) myname);
 
-  xmlNewTextChild (child, NULL, COMMANDXML_TAG_SCHEME, (xmlChar *) myscheme);
-
   xmlNewTextChild (child, NULL, COMMANDXML_TAG_LABEL, (xmlChar *) mylabel);
 
-
   xmlNewTextChild (child, NULL, COMMANDXML_TAG_TOOLTIP, (xmlChar *) mytooltip);
-  xmlSaveFormatFileEnc (filename, doc, "UTF-8", 1);
 
+  xmlSaveFormatFileEnc (filename, doc, XML_ENCODING, 1);
   xmlFreeDoc (doc);
   return 0;
 }
+
+gint
+save_command_data (gchar * filename, gchar * myscheme)
+{
+  g_file_set_contents (filename, myscheme, -1, NULL);
+  return 0;
+}
+
+gchar *
+load_command_data (GtkAction * action)
+{
+  const gchar *basename = gtk_action_get_name (action);
+  gchar *filename = g_strconcat (basename, SCM_EXT, NULL);
+  gchar* path = NULL;
+  gchar* scheme = NULL;
+  GError* error = NULL;
+
+  // Locate the script
+  gchar* dir = find_command_dir(action, filename);
+  if(!dir)
+  {
+    gchar* msg = g_strdup_printf(_("Unable to locate the script %s"), filename);
+    warningdialog (msg);
+    g_free(msg);
+    g_free(filename);
+    return NULL;
+  }
+
+  // Load the script
+  path = g_build_filename(dir, filename, NULL);
+  g_free(filename);
+  if(!g_file_get_contents (path, &scheme, NULL, &error))
+  {
+    gchar* msg = g_strdup_printf(_("Unable to load the script %s"), path);
+    warningdialog (msg);
+    g_free(msg);
+    g_free(path);
+    return NULL;
+  }
+  g_free(path);
+
+  g_object_set_data (G_OBJECT (action), "scheme", scheme);
+  
+  // Load the init script if there is one
+  path = g_build_filename (dir, INIT_SCM, NULL);
+  if (g_file_test (path, G_FILE_TEST_EXISTS))
+    //scm_c_primitive_load(path);Use scm_c_primitive_load together with scm_internal_catch and scm_handle_by_message_no_exit instead. 
+    eval_file_with_catch (path);
+  g_free (path);
+
+  g_free (dir);
+
+  return scheme;
+}
