@@ -40,10 +40,8 @@ add_font_directory (gchar * fontpath)
 {
 #ifdef G_OS_WIN32
   AddFontResource (fontpath);
-  FcConfigAppFontAddDir (NULL, (FcChar8*) fontpath);
-#else
-  FcConfigAppFontAddDir (NULL, (FcChar8*) fontpath);
 #endif
+  FcConfigAppFontAddDir (NULL, (FcChar8*) fontpath);
 }
 
 void
@@ -51,11 +49,8 @@ add_font_file (gchar * fontname)
 {
 #ifdef G_OS_WIN32
   AddFontResource (fontname);
-  FcConfigAppFontAddFile (NULL, (FcChar8*) fontname);
-
-#else
-  FcConfigAppFontAddFile (NULL, (FcChar8*) fontname);
 #endif
+  FcConfigAppFontAddFile (NULL, (FcChar8*) fontname);
 }
 
 #ifdef G_OS_WIN32
@@ -939,14 +934,12 @@ initdir ()
   GError *error = NULL;
   if (!gbr_init (&error) && (error != (GError *) GBR_INIT_ERROR_DISABLED))
     {
-#ifdef DEBUG
-      g_print ("BinReloc failed to initialize:\n");
-      g_print ("Domain: %d (%s)\n", (int) error->domain, g_quark_to_string (error->domain));
-      g_print ("Code: %d\n", error->code);
-      g_print ("Message: %s\n", error->message);
+      g_debug ("BinReloc failed to initialize:\n");
+      g_debug ("Domain: %d (%s)\n", (int) error->domain, g_quark_to_string (error->domain));
+      g_debug ("Code: %d\n", error->code);
+      g_debug ("Message: %s\n", error->message);
       g_error_free (error);
-      g_print ("----------------\n");
-#endif
+      g_debug ("----------------\n");
     }
 #endif /* not G_OS_WIN32 */
 }
@@ -1456,6 +1449,7 @@ append_directives_information (GString * selection, GList * directives)
       DenemoDirective *directive = directives->data;
       const gchar *label = get_label_for_command (directive->tag->str);
       const gchar *menupath = get_menu_path_for_command (directive->tag->str);
+      const gchar *tooltip = get_tooltip_for_command (directive->tag->str);
       if(label)
 				g_string_append_printf (selection, _("Directive for command: \"%s\"\n"), label);
       else
@@ -1463,9 +1457,11 @@ append_directives_information (GString * selection, GList * directives)
 			if(menupath)
 				g_string_append_printf (selection, _("Menu location for this command: \"%s\"\n"), menupath);
       if(directive->prefix)
-				 g_string_append_printf (selection, _("LilyPond inserted in prefix to this note is \"%s\"\n"), directive->prefix->str);
+				 g_string_append_printf (selection, _("LilyPond inserted in prefix to this object is \"%s\"\n"), directive->prefix->str);
 			if(directive->postfix)
-				 g_string_append_printf (selection, _("LilyPond inserted in postfix to this note is \"%s\"\n"), directive->postfix->str);
+				 g_string_append_printf (selection, _("LilyPond inserted in postfix to this object is \"%s\"\n"), directive->postfix->str);
+      if(tooltip)
+        g_string_append_printf (selection, _("The help for the command that created this directive is:\n\"%s\""), tooltip);
     }
   while (directives->next && (directives = directives->next));
 }
@@ -1515,16 +1511,26 @@ display_current_object (void)
                     selection = g_string_append (selection, _("a one-note chord.\n"));
                   }
                 if (thechord->slur_begin_p)
-                  selection = g_string_append (selection, _("\nA slur starts from here.\n" "There should be a matching end slur later."));
+                  selection = g_string_append (selection, _("A slur starts from here.\n" "There should be a matching end slur later.\n"));
                 if (thechord->slur_end_p)
-                  selection = g_string_append (selection, _("\nA slur ends here\n" "There should be a matching start slur earlier."));
+                  selection = g_string_append (selection, _("A slur ends here\n" "There should be a matching start slur earlier.\n"));
                 if (thechord->is_tied)
-                  selection = g_string_append (selection, _("\nThis is tied to the following note or chord.\n" "The following note or chord should have the same pitch"));
+                  selection = g_string_append (selection, _("This is tied to the following note or chord.\n" "The following note or chord should have the same pitch"));
+                if (thechord->is_grace && !(thechord->is_grace & GRACED_NOTE))
+                  selection = g_string_append (selection, _("This is an acciacatura note\n"));
+                if (thechord->is_grace & GRACED_NOTE)
+                  selection = g_string_append (selection, _("This is an appogiatura note\n"));
+                if (curObj->isinvisible)
+                  selection = g_string_append (selection, _("This note denotes a rhythm - use a MIDI keyboard to add pitches by playing.\n"));
+
+
+
 
                 note *thenote = findnote (curObj, gui->si->cursor_y);
                 if (thenote && gui->si->cursor_y==thenote->mid_c_offset)
                   {
-										g_string_append_printf (selection, _("\nWithin the chord the cursor is on the note %s \n"),
+  
+										g_string_append_printf (selection, _("Within the chord the cursor is on the note %s \n"),
 											mid_c_offsettolily (thenote->mid_c_offset, thenote->enshift));
                     if (thenote->directives)
                       {
@@ -1532,10 +1538,13 @@ display_current_object (void)
                         append_directives_information (selection, thenote->directives);
                       }
                   }
+                if ((thechord->notes->next) && curObj->isinvisible)
+                        warning = g_string_append (warning, _("This rhythm has extra notes added to it, delete them and use the foot-pedal or Alt key to enter chords with the MIDI controller.\n"));
+
               }
             else
               {
-                selection = g_string_append (selection, _("a rest."));
+                selection = g_string_append (selection, _("a rest.\n"));
                 if (thechord->slur_begin_p)
                   warning = g_string_append (warning, _("This rest has a slur start on it, use the Notes/Rests → Slurs menu to remove it"));
                 if (thechord->slur_end_p)
@@ -1543,11 +1552,18 @@ display_current_object (void)
                 if (thechord->is_tied)
                   warning = g_string_append (warning, _("This rest has a tie starting on it, use the Notes/Rests → Ties menu to remove it"));
 
+                  
+                if (curObj->isinvisible)
+                  selection = g_string_append (selection, _("This rest will not print, just act as a spacer.\n"));
+                if (thechord->is_grace && curObj->isinvisible)
+                  warning = g_string_append (warning, _("This rest has the grace attribute set: this can be used to avoid a bug in the print view.\n"));
+
               }
             if (thechord->directives) {
 							selection = g_string_append (selection, _("Attached to the chord:"));
               append_directives_information (selection, thechord->directives);
 						}
+          g_string_append_printf (selection, _("This starts %d/384 quarter notes into the measure and lasts %d/384 quarter notes.\n"), curObj->starttick, curObj->durinticks);
 
           }
           break;
@@ -1624,11 +1640,15 @@ display_current_object (void)
 							directive->tag = g_string_new("<Unknown Tag>");//shouldn't happen
             const gchar *label = get_label_for_command(directive->tag->str);
             const gchar *menupath = get_menu_path_for_command(directive->tag->str);
+            const gchar *tooltip = get_tooltip_for_command (directive->tag->str);
+
             if(label)
                g_string_append_printf (selection, _("a Denemo Directive: (%s)"), label);
             else
 							g_string_append_printf (selection, _("a Denemo Directive: (%s)"), directive->tag->str);
-            
+            if(tooltip)
+                g_string_append_printf (selection, _("\nThe help for the command that created this directive is \"%s\""), tooltip);
+
            g_string_append_printf (selection, _("%s"), directive->x ? _("\nNot all layouts\n") : directive->y ? _("\nOnly for one Layout\n"): "\n");
            if(menupath)
 						g_string_append_printf (selection, _("Menu location for this command: \"%s\"\n"), menupath);
@@ -1764,9 +1784,9 @@ write_status (DenemoGUI * gui)
   gint index = g_list_index (gui->movements, gui->si);
   g_string_printf (status, "%s %d: %s: ", enshift_string (gui->si->pending_enshift), index + 1, selection);
   if (gui->si->smf && (gui->si->smfsync == gui->si->changecount) && Denemo.prefs.playback_controls)
-    g_string_append_printf (status, "%d min %.2f sec %.2f %.2f", minutes, seconds, early, late);
+    g_string_append_printf (status, _("%d min %.2f sec %.2f %.2f"), minutes, seconds, early, late);
   else
-    g_string_append_printf (status, " Staff %d Measure %d Position %d %s", gui->si->currentstaffnum, gui->si->currentmeasurenum, gui->si->cursor_x + 1, gui->si->cursor_appending ? "Appending" : "Not Appending" /*not understood this one... , gui->si->cursoroffend?"Off End":"Not Off End" */ );
+    g_string_append_printf (status, _(" Staff %d Measure %d Position %d %s"), gui->si->currentstaffnum, gui->si->currentmeasurenum, gui->si->cursor_x + 1, gui->si->cursor_appending ? _("Appending") : _("Not Appending") /*not understood this one... , gui->si->cursoroffend?"Off End":"Not Off End" */ );
 
   if (Denemo.prefs.midi_in_controls)
     {
@@ -2282,3 +2302,54 @@ initialize_keystroke_help (void)
     }
   gtk_widget_hide (KeyStrokes);
 }
+
+/**
+ * find_dir_for_file:
+ * @filename: The file to search
+ * @dirs: A dir paths array, ending by NULL, where to search.
+ *
+ * Finds the first dir in the list that contains 'filename', and free the array.
+ *
+ * Returns: The dir path if found, NULL either
+ **/
+gchar*
+find_dir_for_file(gchar* filename, gchar* dirs[])
+{
+  gchar *dir = NULL;
+  gchar *path = NULL;
+  gint i;
+
+  for(i = 0; dirs[i]; i++)
+  {
+    if(!dir)
+    {
+      path = g_build_filename (dirs[i], filename, NULL);
+      if(g_file_test (path, G_FILE_TEST_EXISTS))
+        dir = g_strdup(dirs[i]);
+      g_free(path);
+    }
+    g_free(dirs[i]);
+  }
+  return dir;
+}
+
+/**
+ * find_path_for_file:
+ * @filename: The file to search
+ * @dirs: A dir paths array, ending by NULL, where to search.
+ *
+ * Finds the first dir in the list that contains 'filename', and free the array.
+ *
+ * Returns: The file path if found, NULL either
+ **/
+gchar*
+find_path_for_file(gchar* filename, gchar* dirs[])
+{
+  gchar* dir = find_dir_for_file (filename, dirs);
+  if(dir){
+    gchar* path = g_build_filename(dir, filename, NULL);
+    g_free(dir);
+    return path;
+  }
+  return NULL;
+}
