@@ -40,7 +40,7 @@
 #include "libguile.h"
 
 #define EXTRA_ACCELS "extra.accels"
-
+#define INIT_SCM "init.scm"
 
 void newview (GtkAction * action, gpointer param);
 void free_movements (DenemoGUI * gui);  /* frees all movement data (i.e. the DenemoScore objects) from gui, leaving gui interface intact */
@@ -70,7 +70,7 @@ GError *execute_script_file (gchar * filename);
 
 gboolean activate_script (GtkAction * action, DenemoScriptParam * param);
 void create_scheme_function_for_script (gchar * name);
-void inner_main (void *closure, int argc, char **argv);
+void* inner_main (void* data);
 
 gchar *create_xbm_data_from_pixbuf (GdkPixbuf * pixbuf, int lox, int loy, int hix, int hiy);
 gchar *get_icon_for_name (gchar * name, gchar * label);
@@ -112,4 +112,5 @@ void define_scheme_bool_variable (gchar * varname, gint value, gchar * tooltip);
 SCM scheme_next_note (SCM optional);
 void finish_recording(void);
 void define_scheme_literal_variable (gchar * varname, gchar * value, gchar * tooltip);
+gint eval_file_with_catch (gchar * filename);
 #endif
